about summary refs log tree commit diff stats
path: root/027call_ingredient.cc
diff options
context:
space:
mode:
authorKartik K. Agaram <vc@akkartik.com>2016-09-16 23:52:15 -0700
committerKartik K. Agaram <vc@akkartik.com>2016-09-16 23:57:55 -0700
commit78c5020531a09a242f1d21b94ab128001c04bcdf (patch)
tree2b0eaef5064ca8ab0267b04983d111bd0bd87239 /027call_ingredient.cc
parent8752e6b09e302c88702ab6e7a965daa624ba5213 (diff)
downloadmu-78c5020531a09a242f1d21b94ab128001c04bcdf.tar.gz
3374
Diffstat (limited to '027call_ingredient.cc')
-rw-r--r--027call_ingredient.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/027call_ingredient.cc b/027call_ingredient.cc
index c9917614..d2f8a000 100644
--- a/027call_ingredient.cc
+++ b/027call_ingredient.cc
@@ -57,7 +57,7 @@ case NEXT_INGREDIENT: {
     if (current_recipe_name() == "main") {
       // no ingredient types since the call might be implicit; assume ingredients are always strings
       // todo: how to test this?
-      if (!is_mu_string(product))
+      if (!is_mu_text(product))
         raise << "main: wrong type for ingredient '" << product.original_string << "'\n" << end();
     }
     else if (!types_coercible(product,
@@ -171,10 +171,10 @@ case INGREDIENT: {
   break;
 }
 
 //: a particularly common array type is the string, or address:array:character
 :(code)
-bool is_mu_string(reagent/*copy*/ x) {
-  // End Preprocess is_mu_string(reagent x)
+bool is_mu_text(reagent/*copy*/ x) {
+  // End Preprocess is_mu_text(reagent x)
   return x.type
       && !x.type->atom
       && x.type->left->atom
@@ -171,10 +171,10 @@ case INGREDIENT: {
 }
 
-//: a particularly common array type is the string, or address:array:character
+//: a particularly common array type is the text, or address:array:character
 :(code)